Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterController ¶
type ClusterController struct {
Name string
BeforeReconcile func(key string)
AfterReconcile func(key string, err error)
Informers *sharedinformers.SharedInformers
// contains filtered or unexported fields
}
ClusterController implements the controller.ClusterController interface
func NewClusterController ¶
func NewClusterController(config *rest.Config, si *sharedinformers.SharedInformers) *ClusterController
NewController returns a new ClusterController for responding to Cluster events
func (*ClusterController) GetName ¶
func (c *ClusterController) GetName() string
func (*ClusterController) LookupAndReconcile ¶
func (c *ClusterController) LookupAndReconcile(key string) (err error)
func (*ClusterController) Run ¶
func (c *ClusterController) Run(stopCh <-chan struct{})
type ClusterControllerImpl ¶
type ClusterControllerImpl struct {
builders.DefaultControllerFns
// contains filtered or unexported fields
}
+controller:group=cluster,version=v1alpha1,kind=Cluster,resource=clusters
func (*ClusterControllerImpl) Get ¶
func (c *ClusterControllerImpl) Get(namespace, name string) (*v1alpha1.Cluster, error)
func (*ClusterControllerImpl) Init ¶
func (c *ClusterControllerImpl) Init(arguments sharedinformers.ControllerInitArguments)
Init initializes the controller and is called by the generated code Register watches for additional resource types here.
Click to show internal directories.
Click to hide internal directories.